"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.getEntries = exports.getEntryOutputFile = void 0;

var _path = require("path");

var _plugin = _interopRequireDefault(require("react-entry-loader/plugin"));

var _entry = _interopRequireDefault(require("react-entry-loader/entry"));

var _webpack = _interopRequireDefault(require("webpack"));

var _copyWebpackPlugin = _interopRequireDefault(require("copy-webpack-plugin"));

var _miniCssExtractPlugin = _interopRequireDefault(require("mini-css-extract-plugin"));

/* eslint-env node */

/* eslint no-console: 0 */

/* eslint max-params: 0 */
// eslint-disable-next-line
const getEntryOutputFile = entryFile => {
  if (entryFile.endsWith('.js')) {
    entryFile = entryFile.substring(0, entryFile.lastIndexOf('.js'));
  } else {
    throw new Error('Must be a .html.js file');
  }

  if (entryFile.endsWith('.html')) {
    return entryFile;
  }

  throw new Error('Must be a .html.js file');
};

exports.getEntryOutputFile = getEntryOutputFile;

const getEntries = (entryPoints, appUrl, version) => {
  const entries = {};

  for (const entryPoint of entryPoints) {
    const entryFile = (0, _path.basename)(entryPoint);
    const [entryKey] = entryFile.split('.');
    entries[entryKey] = ['@babel/polyfill', (0, _entry.default)({
      output: getEntryOutputFile(entryFile),
      appUrl,
      version
    })(`./src/${entryPoint}`)];
  }

  return entries;
};

exports.getEntries = getEntries;

const getStyleModuleLoaders = (useSass, isProduction, sassRootTheme) => {
  const cssStyleModuleLoaders = [_miniCssExtractPlugin.default.loader, {
    loader: 'css-loader',
    options: {
      modules: true,
      sourceMap: !isProduction,
      importLoaders: 2,
      localIdentName: '[name]_[local]_[hash:base64:5]',
      camelCase: true
    }
  }, {
    loader: 'postcss-loader',
    options: {
      /* istanbul ignore next */
      plugins:
      /* istanbul ignore next */
      () => [
      /* istanbul ignore next */
      require('postcss-nested')({
        /* options */
      }), require('autoprefixer')],
      sourceMap: !isProduction
    }
  }];
  const sassStyleModuleLoaders = [{
    loader: 'sass-loader',
    options: {
      sourceMap: !isProduction,
      // adds app-theme overrides to component's custom themes
      data: `@import "src/${sassRootTheme}";`,
      includePaths: [(0, _path.resolve)(process.cwd()), (0, _path.resolve)(process.cwd(), './node_modules')]
    }
  }];

  if (useSass) {
    return [...cssStyleModuleLoaders, ...sassStyleModuleLoaders];
  }

  return cssStyleModuleLoaders;
};
/*
  NOTE that this webpack configuration currently only supports the new
  ReactEntryLoaderPlugin way of creating entry points and does not use
  HtmlWebpackPlugin.  Therefore all paths to entry files must be of format
  entry.html.js.
 */


var _default = (buildEntries, buildOutputPath, devServerPort, faviconPath, useSass = false, jsxIncludePaths = ['src'], sassRootTheme = 'theme.scss') => (nodeEnv, deployUrl, deployPath, version) => {
  const isProduction = nodeEnv === 'production';
  const appUrl = deployUrl;
  const cwd = process.cwd();
  console.log(`
    Running webpack with config from '.build/config.json':
    NODE_ENV=${nodeEnv}
    version=${version}
    app-url=${appUrl}
  `);
  return {
    mode: isProduction ? 'production' : 'development',
    entry: { ...getEntries(buildEntries, appUrl, version)
    },
    output: {
      path: (0, _path.resolve)(cwd, buildOutputPath),
      filename: '[name]-[contenthash].js',
      // improve paths in devtools

      /* istanbul ignore next */
      devtoolModuleFilenameTemplate:
      /* istanbul ignore next */
      info =>
      /* istanbul ignore next */
      `webpack:///${(0, _path.relative)(cwd, info.absoluteResourcePath)}`
    },
    optimization: {
      minimize: isProduction,
      runtimeChunk: {
        name: 'runtime'
      },
      splitChunks: {
        chunks: 'all',
        name: !isProduction,
        cacheGroups: {
          default: false,
          react: {
            test: /[\\/]node_modules[\\/]react/,
            name: 'react',
            chunks: 'all'
          }
        }
      }
    },
    plugins: [new _plugin.default(), new _copyWebpackPlugin.default([{
      from: `src/${faviconPath}`
    }]), new _miniCssExtractPlugin.default({
      chunkFilename: '[name]-[contenthash].css'
    })],
    module: {
      rules: [{
        test: useSass ? /(\.scss|\.css)$/ : /(\.css)$/,
        use: getStyleModuleLoaders(useSass, isProduction, sassRootTheme)
      }, {
        test: /\.(png|jpg|svg|ico|gif)$/,
        loader: 'url-loader?limit=1'
      }, {
        test: /\.jsx?$/,
        include: jsxIncludePaths.map(modulePath => (0, _path.resolve)(cwd, modulePath)),
        loader: 'babel-loader',
        options: {
          // making sure babel gets the right environment and thus
          // picks up the correct config.
          envName: nodeEnv
        }
      }]
    },
    devtool: isProduction ? false : '#cheap-module-source-map',
    devServer: {
      port: devServerPort,
      host: '0.0.0.0',
      inline: true,
      stats: 'minimal',
      contentBase: `./${(0, _path.dirname)(buildOutputPath)}`,
      publicPath: `/${deployPath}/`,
      historyApiFallback: {
        rewrites: [{
          from: /^\/$/,
          to: `/${deployPath}/`
        }]
      }
    }
  };
};

exports.default = _default;